@@ -1,10 +1,10 @@
-/* $Id: VBoxNetFlt-linux.c 82648 2012-12-12 11:40:37Z aleksey $ */
+/* $Id: VBoxNetFlt-linux.c 83687 2013-02-08 12:50:49Z fmehnert $ */
 /** @file
  * VBoxNetFlt - Network Filter Driver (Host), Linux Specific Code.
  */
 
 /*
- * Copyright (C) 2006-2008 Oracle Corporation
+ * Copyright (C) 2006-2013 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -795,7 +795,7 @@ static int vboxNetFltLinuxPacketHandler(struct sk_buff *pBuf,
     if (pDev != pSkbDev)
     {
         Log(("vboxNetFltLinuxPacketHandler: Devices do not match, pThis may be wrong! pThis=%p\n", pThis));
-        dev_kfree_skb(pBuf);
+        kfree_skb(pBuf); /* This is a failure, so we use kfree_skb instead of dev_kfree_skb. */
         return 0;
     }
 
@@ -814,7 +814,7 @@ static int vboxNetFltLinuxPacketHandler(struct sk_buff *pBuf,
          */
         unsigned int uMacLen = pBuf->mac_len;
         struct sk_buff *pCopy = skb_copy(pBuf, GFP_ATOMIC);
-        kfree_skb(pBuf);
+        dev_kfree_skb(pBuf);
         if (!pCopy)
         {
             LogRel(("VBoxNetFlt: Failed to allocate packet buffer, dropping the packet.\n"));
