@@ -1,10 +1,10 @@
-/* $Id: the-linux-kernel.h 74568 2011-10-27 10:15:29Z fmehnert $ */
+/* $Id: the-linux-kernel.h 83687 2013-02-08 12:50:49Z fmehnert $ */
 /** @file
  * IPRT - Include all necessary headers for the Linux kernel.
  */
 
 /*
- * Copyright (C) 2006-2011 Oracle Corporation
+ * Copyright (C) 2006-2012 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -35,7 +35,7 @@
 #define bool linux_bool
 
 #include <linux/version.h>
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 33)
 # include <generated/autoconf.h>
 #else
 # ifndef AUTOCONF_INCLUDED
@@ -64,6 +64,9 @@
 #  define KBUILD_STR(s) #s
 # endif
 #endif
+# if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 3, 0)
+#  include <linux/kconfig.h> /* for macro IS_ENABLED */
+# endif
 #include <linux/string.h>
 #include <linux/spinlock.h>
 #include <linux/slab.h>
@@ -239,7 +242,7 @@ DECLINLINE(unsigned long) msecs_to_jiffies(unsigned int cMillies)
 /* accounting. */
 # if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 0)
 #  ifdef VM_ACCOUNT
-#   define MY_DO_MUNMAP(a,b,c) do_munmap(a, b, c, 0) /* should it be 1 or 0? */
+#   define USE_RHEL4_MUNMAP
 #  endif
 # endif
 
@@ -266,10 +269,6 @@ DECLINLINE(unsigned long) msecs_to_jiffies(unsigned int cMillies)
 # endif  /* !RT_ARCH_AMD64 */
 #endif /* !NO_REDHAT_HACKS */
 
-#ifndef MY_DO_MUNMAP
-# define MY_DO_MUNMAP(a,b,c) do_munmap(a, b, c)
-#endif
-
 #ifndef MY_CHANGE_PAGE_ATTR
 # ifdef RT_ARCH_AMD64 /** @todo This is a cheap hack, but it'll get around that 'else BUG();' in __change_page_attr().  */
 #  define MY_CHANGE_PAGE_ATTR(pPages, cPages, prot) \
